"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.globalConfig = globalConfig;
exports.persistConfig = persistConfig;
exports.uploadConfig = uploadConfig;
const path = require("node:path");
const env_js_1 = require("./env.js");
function globalConfig(options, context) {
    const { projectConfig } = context;
    const { root: projectRoot = '' } = projectConfig ?? {};
    // For better debugging use `--verbose --no-progress` as default
    const { verbose, progress, config } = options;
    return {
        verbose: !!verbose,
        progress: !!progress,
        config: config ?? path.join(projectRoot, 'code-pushup.config.ts'),
    };
}
function persistConfig(options, context) {
    const { projectConfig, workspaceRoot } = context;
    const { name: projectName = '' } = projectConfig ?? {};
    const { format, outputDir = path.join(workspaceRoot, '.code-pushup', projectName), // always in <root>/.code-pushup/<project-name>,
    filename, } = options;
    return {
        outputDir,
        ...(format ? { format } : {}),
        ...(filename ? { filename } : {}),
    };
}
function uploadConfig(options, context) {
    const { projectConfig, workspaceRoot } = context;
    const { name: projectName } = projectConfig ?? {};
    const { projectPrefix, server, apiKey, organization, project, timeout } = options;
    const applyPrefix = workspaceRoot === '.';
    const prefix = projectPrefix ? `${projectPrefix}-` : '';
    return {
        ...(projectName
            ? {
                project: applyPrefix ? `${prefix}${projectName}` : projectName,
            }
            : {}),
        ...(0, env_js_1.parseEnv)(process.env),
        ...Object.fromEntries(Object.entries({ server, apiKey, organization, project, timeout }).filter(([_, v]) => v !== undefined)),
    };
}
//# sourceMappingURL=config.js.map